@@ -2,32 +2,32 @@
 
 // See "HOW TO ADD A COMMAND-LINE ARGUMENT" in README-maintainer.
 
-#include <iostream>
-#include <string.h>
-#include <stdlib.h>
 #include <cstdio>
 #include <ctype.h>
+#include <iostream>
 #include <memory>
 #include <sstream>
+#include <stdlib.h>
+#include <string.h>
 
-#include <qpdf/QUtil.hh>
-#include <qpdf/QTC.hh>
-#include <qpdf/QPDFCryptoProvider.hh>
-#include <qpdf/QPDFArgParser.hh>
-#include <qpdf/QPDFJob.hh>
 #include <qpdf/QIntC.hh>
+#include <qpdf/QPDFArgParser.hh>
+#include <qpdf/QPDFCryptoProvider.hh>
+#include <qpdf/QPDFJob.hh>
+#include <qpdf/QPDFLogger.hh>
+#include <qpdf/QTC.hh>
+#include <qpdf/QUtil.hh>
 
 namespace
 {
     class ArgParser
     {
       public:
-        ArgParser(QPDFArgParser& ap,
-                  std::shared_ptr<QPDFJob::Config> c_main);
+        ArgParser(QPDFArgParser& ap, std::shared_ptr<QPDFJob::Config> c_main);
         void parseOptions();
 
       private:
-#       include <qpdf/auto_job_decl.hh>
+#include <qpdf/auto_job_decl.hh>
 
         void usage(std::string const& message);
         void initOptionTables();
@@ -44,10 +44,10 @@ namespace
         bool gave_input;
         bool gave_output;
     };
-}
+} // namespace
 
-ArgParser::ArgParser(QPDFArgParser& ap,
-                     std::shared_ptr<QPDFJob::Config> c_main) :
+ArgParser::ArgParser(
+    QPDFArgParser& ap, std::shared_ptr<QPDFJob::Config> c_main) :
     ap(ap),
     c_main(c_main),
     pages_password(nullptr),
@@ -62,33 +62,27 @@ ArgParser::ArgParser(QPDFArgParser& ap,
 void
 ArgParser::initOptionTables()
 {
-
-#   include <qpdf/auto_job_init.hh>
-    this->ap.addFinalCheck([this](){c_main->checkConfiguration();});
+#include <qpdf/auto_job_init.hh>
+    this->ap.addFinalCheck([this]() { c_main->checkConfiguration(); });
     // add_help is defined in auto_job_help.hh
     add_help(this->ap);
     // Special case: ignore -- at the top level. This undocumented
     // behavior is for backward compatibility; it was unintentionally
     // the case prior to 10.6, and some users were relying on it.
     this->ap.selectMainOptionTable();
-    this->ap.addBare("--", [](){});
+    this->ap.addBare("--", []() {});
 }
 
 void
 ArgParser::argPositional(std::string const& arg)
 {
-    if (! this->gave_input)
-    {
+    if (!this->gave_input) {
         c_main->inputFile(arg);
         this->gave_input = true;
-    }
-    else if (! this->gave_output)
-    {
+    } else if (!this->gave_output) {
         c_main->outputFile(arg);
         this->gave_output = true;
-    }
-    else
-    {
+    } else {
         usage("unknown argument " + arg);
     }
 }
@@ -111,10 +105,10 @@ void
 ArgParser::argVersion()
 {
     auto whoami = this->ap.getProgname();
-    std::cout
-        << whoami << " version " << QPDF::QPDFVersion() << std::endl
-        << "Run " << whoami << " --copyright to see copyright and license information."
-        << std::endl;
+    *QPDFLogger::defaultLogger()->getInfo()
+        << whoami << " version " << QPDF::QPDFVersion() << "\n"
+        << "Run " << whoami
+        << " --copyright to see copyright and license information.\n";
 }
 
 void
@@ -124,48 +118,42 @@ ArgParser::argCopyright()
     // Make sure the output looks right on an 80-column display.
     //               1         2         3         4         5         6         7         8
     //      12345678901234567890123456789012345678901234567890123456789012345678901234567890
-    std::cout
+    *QPDFLogger::defaultLogger()->getInfo()
         << this->ap.getProgname()
-        << " version " << QPDF::QPDFVersion() << std::endl
-        << std::endl
-        << "Copyright (c) 2005-2022 Jay Berkenbilt"
-        << std::endl
-        << "QPDF is licensed under the Apache License, Version 2.0 (the \"License\");"
-        << std::endl
-        << "you may not use this file except in compliance with the License."
-        << std::endl
-        << "You may obtain a copy of the License at"
-        << std::endl
-        << std::endl
-        << "  http://www.apache.org/licenses/LICENSE-2.0"
-        << std::endl
-        << std::endl
-        << "Unless required by applicable law or agreed to in writing, software"
-        << std::endl
-        << "distributed under the License is distributed on an \"AS IS\" BASIS,"
-        << std::endl
-        << "WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied."
-        << std::endl
-        << "See the License for the specific language governing permissions and"
-        << std::endl
-        << "limitations under the License."
-        << std::endl
-        << std::endl
-        << "Versions of qpdf prior to version 7 were released under the terms"
-        << std::endl
-        << "of version 2.0 of the Artistic License. At your option, you may"
-        << std::endl
-        << "continue to consider qpdf to be licensed under those terms. Please"
-        << std::endl
-        << "see the manual for additional information."
-        << std::endl;
+        << " version " << QPDF::QPDFVersion() << "\n"
+        << "\n"
+        << "Copyright (c) 2005-2022 Jay Berkenbilt\n"
+        << "QPDF is licensed under the Apache License, Version 2.0 (the \"License\");\n"
+        << "you may not use this file except in compliance with the License.\n"
+        << "You may obtain a copy of the License at\n"
+        << "\n"
+        << "  http://www.apache.org/licenses/LICENSE-2.0\n"
+        << "\n"
+        << "Unless required by applicable law or agreed to in writing, software\n"
+        << "distributed under the License is distributed on an \"AS IS\" BASIS,\n"
+        << "WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n"
+        << "See the License for the specific language governing permissions and\n"
+        << "limitations under the License.\n"
+        << "\n"
+        << "Versions of qpdf prior to version 7 were released under the terms\n"
+        << "of version 2.0 of the Artistic License. At your option, you may\n"
+        << "continue to consider qpdf to be licensed under those terms. Please\n"
+        << "see the manual for additional information.\n";
     // clang-format on
 }
 
 void
-ArgParser::argJsonHelp()
+ArgParser::argJsonHelp(std::string const& parameter)
 {
-    std::cout << QPDFJob::json_out_schema_v1() << std::endl;
+    int version = JSON::LATEST;
+    if (!(parameter.empty() || (parameter == "latest"))) {
+        version = QUtil::string_to_int(parameter.c_str());
+    }
+    if ((version < 1) || (version > JSON::LATEST)) {
+        usage(std::string("unsupported json version ") + parameter);
+    }
+    *QPDFLogger::defaultLogger()->getInfo()
+        << QPDFJob::json_out_schema(version) << "\n";
 }
 
 void
@@ -173,12 +161,10 @@ ArgParser::argShowCrypto()
 {
     auto crypto = QPDFCryptoProvider::getRegisteredImpls();
     std::string default_crypto = QPDFCryptoProvider::getDefaultProvider();
-    std::cout << default_crypto << std::endl;
-    for (auto const& iter: crypto)
-    {
-        if (iter != default_crypto)
-        {
-            std::cout << iter << std::endl;
+    *QPDFLogger::defaultLogger()->getInfo() << default_crypto << "\n";
+    for (auto const& iter: crypto) {
+        if (iter != default_crypto) {
+            *QPDFLogger::defaultLogger()->getInfo() << iter << "\n";
         }
     }
 }
@@ -187,8 +173,7 @@ void
 ArgParser::argEncrypt()
 {
     this->accumulated_args.clear();
-    if (this->ap.isCompleting() && this->ap.argsLeft() == 0)
-    {
+    if (this->ap.isCompleting() && this->ap.argsLeft() == 0) {
         this->ap.insertCompletion("user-password");
     }
     this->ap.selectOptionTable(O_ENCRYPTION);
@@ -199,16 +184,11 @@ ArgParser::argEncPositional(std::string const& arg)
 {
     this->accumulated_args.push_back(arg);
     size_t n_args = this->accumulated_args.size();
-    if (n_args < 3)
-    {
-        if (this->ap.isCompleting() && (this->ap.argsLeft() == 0))
-        {
-            if (n_args == 1)
-            {
+    if (n_args < 3) {
+        if (this->ap.isCompleting() && (this->ap.argsLeft() == 0)) {
+            if (n_args == 1) {
                 this->ap.insertCompletion("owner-password");
-            }
-            else if (n_args == 2)
-            {
+            } else if (n_args == 2) {
                 this->ap.insertCompletion("40");
                 this->ap.insertCompletion("128");
                 this->ap.insertCompletion("256");
@@ -220,23 +200,16 @@ ArgParser::argEncPositional(std::string const& arg)
     std::string owner_password = this->accumulated_args.at(1);
     std::string len_str = this->accumulated_args.at(2);
     int keylen = 0;
-    if (len_str == "40")
-    {
+    if (len_str == "40") {
         keylen = 40;
         this->ap.selectOptionTable(O_40_BIT_ENCRYPTION);
-    }
-    else if (len_str == "128")
-    {
+    } else if (len_str == "128") {
         keylen = 128;
         this->ap.selectOptionTable(O_128_BIT_ENCRYPTION);
-    }
-    else if (len_str == "256")
-    {
+    } else if (len_str == "256") {
         keylen = 256;
         this->ap.selectOptionTable(O_256_BIT_ENCRYPTION);
-    }
-    else
-    {
+    } else {
         usage("encryption key length must be 40, 128, or 256");
     }
     this->c_enc = c_main->encrypt(keylen, user_password, owner_password);
@@ -253,13 +226,11 @@ ArgParser::argPages()
 void
 ArgParser::argPagesPassword(std::string const& parameter)
 {
-    if (this->pages_password)
-    {
+    if (this->pages_password) {
         QTC::TC("qpdf", "QPDFJob duplicated pages password");
         usage("--password already specified for this file");
     }
-    if (this->accumulated_args.size() != 1)
-    {
+    if (this->accumulated_args.size() != 1) {
         QTC::TC("qpdf", "QPDFJob misplaced pages password");
         usage("in --pages, --password must immediately follow a file name");
     }
@@ -269,15 +240,11 @@ ArgParser::argPagesPassword(std::string const& parameter)
 void
 ArgParser::argPagesPositional(std::string const& arg)
 {
-    if (arg.empty())
-    {
-        if (this->accumulated_args.empty())
-        {
+    if (arg.empty()) {
+        if (this->accumulated_args.empty()) {
             return;
         }
-    }
-    else
-    {
+    } else {
         this->accumulated_args.push_back(arg);
     }
 
@@ -285,8 +252,7 @@ ArgParser::argPagesPositional(std::string const& arg)
     char const* range_p = nullptr;
 
     size_t n_args = this->accumulated_args.size();
-    if (n_args >= 2)
-    {
+    if (n_args >= 2) {
         // will be copied before accumulated_args is cleared
         range_p = this->accumulated_args.at(1).c_str();
     }
@@ -294,41 +260,29 @@ ArgParser::argPagesPositional(std::string const& arg)
     // See if the user omitted the range entirely, in which case we
     // assume "1-z".
     std::string next_file;
-    if (range_p == nullptr)
-    {
-        if (arg.empty())
-        {
+    if (range_p == nullptr) {
+        if (arg.empty()) {
             // The filename or password was the last argument
-            QTC::TC("qpdf", "QPDFJob pages range omitted at end",
-                    this->pages_password ? 0 : 1);
-        }
-        else
-        {
+            QTC::TC(
+                "qpdf",
+                "QPDFJob pages range omitted at end",
+                this->pages_password ? 0 : 1);
+        } else {
             // We need to accumulate some more arguments
             return;
         }
-    }
-    else
-    {
-        try
-        {
+    } else {
+        try {
             QUtil::parse_numrange(range_p, 0);
-        }
-        catch (std::runtime_error& e1)
-        {
+        } catch (std::runtime_error& e1) {
             // The range is invalid.  Let's see if it's a file.
-            if (strcmp(range_p, ".") == 0)
-            {
+            if (strcmp(range_p, ".") == 0) {
                 // "." means the input file.
                 QTC::TC("qpdf", "QPDFJob pages range omitted with .");
-            }
-            else if (QUtil::file_can_be_opened(range_p))
-            {
+            } else if (QUtil::file_can_be_opened(range_p)) {
                 QTC::TC("qpdf", "QPDFJob pages range omitted in middle");
                 // Yup, it's a file.
-            }
-            else
-            {
+            } else {
                 // Give the range error
                 usage(e1.what());
             }
@@ -340,8 +294,7 @@ ArgParser::argPagesPositional(std::string const& arg)
     this->c_pages->pageSpec(file, range, this->pages_password.get());
     this->accumulated_args.clear();
     this->pages_password = nullptr;
-    if (! next_file.empty())
-    {
+    if (!next_file.empty()) {
         this->accumulated_args.push_back(next_file);
     }
 }
@@ -449,7 +402,8 @@ ArgParser::argEndCopyAttachment()
 void
 ArgParser::argJobJsonHelp()
 {
-    std::cout << QPDFJob::job_json_schema_v1() << std::endl;
+    *QPDFLogger::defaultLogger()->getInfo()
+        << QPDFJob::job_json_schema(QPDFJob::LATEST_JOB_JSON) << "\n";
 }
 
 void
@@ -461,27 +415,21 @@ ArgParser::usage(std::string const& message)
 void
 ArgParser::parseOptions()
 {
-    try
-    {
+    try {
         this->ap.parseArgs();
-    }
-    catch (std::runtime_error& e)
-    {
+    } catch (std::runtime_error& e) {
         usage(e.what());
     }
 }
 
 void
-QPDFJob::initializeFromArgv(char const* const argv[],
-                            char const* progname_env)
+QPDFJob::initializeFromArgv(char const* const argv[], char const* progname_env)
 {
-    if (progname_env == nullptr)
-    {
+    if (progname_env == nullptr) {
         progname_env = "QPDF_EXECUTABLE";
     }
     int argc = 0;
-    for (auto k = argv; *k; ++k)
-    {
+    for (auto k = argv; *k; ++k) {
         ++argc;
     }
     QPDFArgParser qap(argc, argv, progname_env);
